#!/usr/local/bin/perl5.8.6

# ********************************************************************
# script to check, if one or more SB running
# written by heiko.wilke(at)wtal(dot)de
# 
# the script is based on:
# ********************************************************************
# Simple announcement script for SLIMP3 using the CLI             v0.4
#
# Copyright (c) 2003 Felix Mueller (felix.mueller(at)gwendesign.com)
#
# This file might be distributed under the same terms as the
# SLIMP3 server (www.slimdevices.com)
# ********************************************************************

# Description:
# checks if one or more player are running
# if yes --> exitcode <> 1
# if no --> exitcode = 0
# Plattform tested:
# - Linux
#
# ********************************************************************

use strict;

use Getopt::Long;
use IO::Socket;

# Parameter
my $szServerIP		= "192.168.80.111";
my $iServerCLIPort	= 9090;
my $szPlayerIPAndPort 	= "";
my $szPlayerName	= "";
my $iPower		= "";
# Internal parameters
my $debug		= 0;	# 0 = off, 1 = on

# Try to open a connection to the SLIMP3 CLI
my $socket = IO::Socket::INET->new(	PeerAddr => $szServerIP,
					PeerPort => $iServerCLIPort,
					Proto => "tcp",
					Type => SOCK_STREAM);
# Check if socket was opened successful
if( !defined( $socket))
{
	print "Cannot connect to $szServerIP:$iServerCLIPort\n";
	exit;
}

# Get the # of players
my $iNumPlayer = sendAndReceive( "player count ?");
$debug && print "No of Players: $iNumPlayer\n";
if( $iNumPlayer eq 0)	# no player
{
    exit; 	
}

# Get the player name and check if player is on
my $iPlayerOn  = 0;
my $iposStart  = 0;
my $iposEnd    = 0;
my $szStr      = "";
my $szIPAdress  = "";

$szStr = sendAndReceive( "players 0 4");    # hole info ueber Player
$szStr =~ s/%3A/':'/ge;                     # ersetze %3A durch :
$debug && print "Info:\n$szStr\n";

for( my $i = 0; $i < $iNumPlayer; $i++)
{
    $szPlayerName 	= sendAndReceive( "player name $i ?");
    $szPlayerName 	= encodeChars( $szPlayerName);
    $iPower 		= sendAndReceive( "$szPlayerName power ?");
    $iPower 		= substr($iPower, length($iPower) - 1, 1);  # letztes Zeichen = iPower
    $debug && print "Playername: $szPlayerName \n";
    $debug && print "Power on?:  $iPower \n";
    if ( $iPower == 1 )
    {
       ### beschaffe player IP-Addresse und setze ping drauf ab
       $iposStart = index( $szStr, "ip:", $iposStart);   # naechste Position von ip:
       $iposEnd   = index( $szStr, ":", $iposStart + 4); # naechster : 
       $szIPAdress = substr( $szStr, $iposStart + 3, $iposEnd - $iposStart - 3);
       $debug && print "IP-Adresse: $szIPAdress\n";  # IP-Adresse
       $iposStart = $iposEnd;
    }
    if( $iPower eq 1 and system ("ping -c 2 $szIPAdress >/dev/null") == 0)
    {
	$iPlayerOn = 1;
    }
}

$debug && print "Playeron:   $iPlayerOn \n";
if( $iPlayerOn eq 1)
{
    exit 255;
}

close( $socket);





# ---------------------------------------------
sub sendAndReceive
{
	my $cmd = shift;

	return if( $cmd eq "");

#	$cmd = $szPlayerIP . encodeChars( ":") . $iPlayerPort . " " . $cmd;

	if( $szPlayerIPAndPort ne "")
	{
		$cmd = $szPlayerIPAndPort . " " . $cmd;
	}
	print $socket "$cmd\n";
	my $answer = <$socket>;
	$answer =~ s/$cmd //i;
	$answer =~ s/\n//;

	return $answer;
}

# ---------------------------------------------
sub encodeChars
{
	my $myChars = $_[0];

	my $MetaChars = quotemeta(' ;,/?\|=+)(*&^%$#@!~`:');
	
	$myChars =~ s/([$MetaChars\"\'\x80-\xFF])/"%" . uc( sprintf( "%2.2x", ord($1)))/eg;

	return $myChars;
}

# ---------------------------------------------
